@@ -293,6 +293,14 @@ class DandiAPIClient(RESTFullAPIClient):
                     lgr.debug("Stored key in keyring")
                 break
 
+    @property
+    def _instance_id(self) -> str:
+        url = self.api_url.rstrip("/")
+        try:
+            return known_instances_rev[url].upper()
+        except KeyError:
+            return url
+
     def get_dandiset(
         self, dandiset_id: str, version_id: Optional[str] = None, lazy: bool = True
     ) -> "RemoteDandiset":
@@ -343,6 +351,9 @@ class DandiAPIClient(RESTFullAPIClient):
                 " upgrade dandi and/or dandischema."
             )
 
+    def get_asset(self, asset_id: str) -> "BaseRemoteAsset":
+        return BaseRemoteAsset._from_metadata(self, self.get(f"/assets/{asset_id}"))
+
 
 class APIBase(BaseModel):
     """Base class for API objects"""
@@ -372,6 +383,9 @@ class Version(APIBase):
     created: datetime
     modified: datetime
 
+    def __str__(self) -> str:
+        return self.identifier
+
 
 class RemoteDandiset:
     """
@@ -401,6 +415,9 @@ class RemoteDandiset:
             self._version = version
         self._data = data
 
+    def __str__(self) -> str:
+        return f"{self.client._instance_id}:{self.identifier}/{self.version_id}"
+
     def _get_data(self) -> Dict[str, Any]:
         if self._data is None:
             self._data = self.client.get(f"/dandisets/{self.identifier}/")
@@ -864,17 +881,9 @@ class RemoteDandiset:
         yield {"status": "done", "asset": a}
 
 
-class RemoteAsset(APIBase):
-    """Representation of an asset retrieved from the API"""
-
-    JSON_EXCLUDE = frozenset(["client", "dandiset_id", "version_id"])
-
+class BaseRemoteAsset(APIBase):
     client: "DandiAPIClient"
-    #: The identifier for the Dandiset to which the asset belongs
-    dandiset_id: str
-    #: The identifier for the version of the Dandiset to which the asset
-    #: belongs
-    version_id: str
+
     #: The asset identifier
     identifier: str = Field(alias="asset_id")
     path: str
@@ -890,13 +899,29 @@ class RemoteAsset(APIBase):
         # underscores, so we have to do it ourselves.
         self._metadata = data.get("metadata", data.get("_metadata"))
 
-    @property
-    def api_path(self) -> str:
-        return f"/dandisets/{self.dandiset_id}/versions/{self.version_id}/assets/{self.identifier}/"
+    def __str__(self) -> str:
+        return f"{self.client._instance_id}:assets/{self.identifier}"
+
+    @classmethod
+    def _from_metadata(
+        self, client: "DandiAPIClient", metadata: Dict[str, Any]
+    ) -> "BaseRemoteAsset":
+        return BaseRemoteAsset(
+            client=client,
+            identifier=metadata["identifier"],
+            path=metadata["path"],
+            size=metadata["contentSize"],
+            modified=metadata["dateModified"],
+            _metadata=metadata,
+        )
 
     @property
-    def download_url(self) -> str:
-        return self.client.get_url(f"{self.api_path}download/")
+    def api_path(self) -> str:
+        return f"/assets/{self.identifier}/"
+
+    @property
+    def base_download_url(self) -> str:
+        return self.client.get_url(f"/assets/{self.identifier}/download/")
 
     def get_metadata(self) -> models.Asset:
         """
@@ -928,35 +953,6 @@ class RemoteAsset(APIBase):
         except KeyError:
             raise NotFoundError(f"No {digest_type} digest found in metadata")
 
-    def set_metadata(self, metadata: models.Asset) -> None:
-        """
-        Set the metadata for the asset to the given value and update the
-        `RemoteAsset` in place.
-        """
-        return self.set_raw_metadata(metadata.json_dict())
-
-    def set_raw_metadata(self, metadata: Dict[str, Any]) -> None:
-        """
-        Set the metadata for the asset to the given value and update the
-        `RemoteAsset` in place.
-        """
-        try:
-            etag = metadata["digest"]["dandi:dandi-etag"]
-        except KeyError:
-            raise ValueError("dandi-etag digest not set in new asset metadata")
-        r = self.client.post(
-            "/blobs/digest/",
-            json={"algorithm": "dandi:dandi-etag", "value": etag},
-        )
-        data = self.client.put(
-            self.api_path, json={"metadata": metadata, "blob_id": r["blob_id"]}
-        )
-        self.identifier = data["asset_id"]
-        self.path = data["path"]
-        self.size = int(data["size"])
-        self.modified = ensure_datetime(data["modified"])
-        self._metadata = data["metadata"]
-
     def get_content_url(
         self,
         regex: str = r".*",
@@ -1001,10 +997,6 @@ class RemoteAsset(APIBase):
             url = urlunparse(urlparse(url)._replace(query=""))
         return url
 
-    def delete(self) -> None:
-        """Delete the asset"""
-        self.client.delete(self.api_path)
-
     def get_download_file_iter(
         self, chunk_size: int = MAX_CHUNK_SIZE
     ) -> Callable[..., Iterator[bytes]]:
@@ -1013,7 +1005,7 @@ class RemoteAsset(APIBase):
         asset to start downloading at) returns a generator of chunks of the
         asset
         """
-        url = self.download_url
+        url = self.base_download_url
 
         def downloader(start_at: int = 0) -> Iterator[bytes]:
             lgr.debug("Starting download from %s", url)
@@ -1044,6 +1036,62 @@ class RemoteAsset(APIBase):
                 fp.write(chunk)
 
 
+class RemoteAsset(BaseRemoteAsset):
+    """
+    Representation of an asset retrieved from the API with associated Dandiset
+    information
+    """
+
+    JSON_EXCLUDE = frozenset(["client", "dandiset_id", "version_id"])
+
+    #: The identifier for the Dandiset to which the asset belongs
+    dandiset_id: str
+    #: The identifier for the version of the Dandiset to which the asset
+    #: belongs
+    version_id: str
+
+    @property
+    def api_path(self) -> str:
+        return f"/dandisets/{self.dandiset_id}/versions/{self.version_id}/assets/{self.identifier}/"
+
+    @property
+    def download_url(self) -> str:
+        return self.client.get_url(f"{self.api_path}download/")
+
+    def set_metadata(self, metadata: models.Asset) -> None:
+        """
+        Set the metadata for the asset to the given value and update the
+        `RemoteAsset` in place.
+        """
+        return self.set_raw_metadata(metadata.json_dict())
+
+    def set_raw_metadata(self, metadata: Dict[str, Any]) -> None:
+        """
+        Set the metadata for the asset to the given value and update the
+        `RemoteAsset` in place.
+        """
+        try:
+            etag = metadata["digest"]["dandi:dandi-etag"]
+        except KeyError:
+            raise ValueError("dandi-etag digest not set in new asset metadata")
+        r = self.client.post(
+            "/blobs/digest/",
+            json={"algorithm": "dandi:dandi-etag", "value": etag},
+        )
+        data = self.client.put(
+            self.api_path, json={"metadata": metadata, "blob_id": r["blob_id"]}
+        )
+        self.identifier = data["asset_id"]
+        self.path = data["path"]
+        self.size = int(data["size"])
+        self.modified = ensure_datetime(data["modified"])
+        self._metadata = data["metadata"]
+
+    def delete(self) -> None:
+        """Delete the asset"""
+        self.client.delete(self.api_path)
+
+
 def upload_part(storage_session, fp, lock, etagger, asset_path, part):
     etag_part = etagger.get_part(part["part_number"])
     if part["size"] != etag_part.size:
